package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````%"````````!``````````%"A````
M`````````$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````&B/````````:(\`````````
M``$```````$````&````@)L```````"`FP$``````(";`0``````^`0`````
M``!0%0```````````0```````@````8```"0FP```````)";`0``````D)L!
M``````#@`0```````.`!````````"`````````!0Y71D!````'2)````````
M=(D```````!TB0```````/0`````````]``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```"`FP```````(";`0``````@)L!``````"`!```````
M`(`$`````````0`````````O;&EB+VQD+6UU<VPM86%R8V@V-"YS;RXQ````
M`````!$```!.````!`````@````A$!``!<`$@"@`$`6`AD"$@B$`!`D`!(F(
M@!A!N@0""$X```!/````4P```%@```!9````8````&$```!B`````````&0`
M``!E`````````&8```!G````:@```````````````:\TZ&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'QV5#R4(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'
MXD?&`5COEWF[XY)\5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````````````````P`'`#@:
M`````````````````````````P`2``"@`0`````````````````!````$@``
M``````````````````````#/`0``$@`````````````````````````)````
M$0````````````````````````#U`0``$0````````````````````````!Q
M`0``$@`````````````````````````0````$@``````````````````````
M``"N`0``$@`````````````````````````8````$@``````````````````
M```````?````$@`````````````````````````"`@``$@``````````````
M``````````"Z`0``$@`````````````````````````H````(```````````
M```````````````?`P``(0````````````````````````!`````$@``````
M``````````````````!&````$@````````````````````````!-````$@``
M``````````````````````#L`@``$@````````````````````````#=`@``
M$@````````````````````````"'`@``$@````````````````````````!4
M````$@`````````````````````````H`@``$@``````````````````````
M``!;````$@````````````````````````"\`@``$@``````````````````
M``````!B````$@````````````````````````!J````$@``````````````
M``````````"E`@``$@````````````````````````!R````$@``````````
M``````````````!X````$@````````````````````````"!````(```````
M``````````````````#6`@``$@````````````````````````"=````$@``
M``````````````````````"B````$@`````````````````````````3`@``
M$0````````````````````````##`@``$@````````````````````````!5
M`@``$@````````````````````````"I````$@``````````````````````
M``!'`@``$@````````````````````````!E`P``$@``````````````````
M```````>`P``$0````````````````````````!Y`@``$@``````````````
M```````````+`P``$@`````````````````````````@`P``$0``````````
M``````````````"P````$@`````````````````````````#`P``$@``````
M``````````````````"Y````$0````````````````````````!_`0``$@``
M``````````````````````#+````(@````````````````````````#:````
M(`````````````````````````#P````$@````````````````````````#.
M`@``$@````````````````````````!E`@``$@``````````````````````
M``#U````$@````````````````````````#[````(```````````````````
M``````"P`@``$@`````````````````````````5`0``$@``````````````
M``````````"?`0``$@`````````````````````````:`0``$@``````````
M``````````````"5`@``$@````````````````````````".`0``$@``````
M```````````````````@`0``$@`````````````````````````Q`0``$@``
M```````````````````````C`@``$@````````````````````````!S````
M$@`````````````````````````T`@``$@````````````````````````!N
M`@``$@````````````````````````#\`@``$@``````````````````````
M```W`0``$@````````````````````````#T`@``$@``````````````````
M``````!+`0``$@`````````````````````````>`@``$@``````````````
M``````````#=`0``$@````````````````````````!2`0``$@``````````
M``````````````!9`0``$@`````````````````````````=`P``(0``````
M``````````````````!J`0``$@````````````````````````!E!```$``3
M`-"P`0`````````````````8`P``$@`)`%`>````````Q`$```````#O`0``
M$@`*`!A,````````!`````````"G`P``$@`)`%`N````````&`8```````!U
M!```$@`)`+0W````````9`````````"$`P``$@`)`(0H````````!```````
M```9!```$@`'`#@:````````!`````````#*`P``$@`)`&@T````````3`,`
M```````?!```$``3`'B@`0````````````````!-!```$@`)`(@H````````
MU`$````````"!```$``3`'B@`0````````````````"5`P``$@`)`)PM````
M````M`````````"T`P``$@`)`,`F````````.`````````"\`P``$@`)`"0M
M````````6`````````#@`P``$@`)`!1)````````<`$```````#U`P``$@`)
M`%PJ````````(``````````.!```$``3`-"P`0````````````````!P!```
M$``3`-"P`0````````````````!*`P``$@`)`#`@````````*``````````M
M!```$@`)`'PJ````````!`$```````#K`P``$0`2`'"@`0``````"```````
M``!&!```$``2`'B@`0`````````````````'!```$@`)`!0@````````````
M```````6!```$@`)`+A(````````7`````````!3`P``$@`)`'PM````````
M(`````````!N`P``$@`)`$PG````````.`$```````!:!```$@`)`(1*````
M````E`$```````!D!```$``3`-"P`0`````````````````Y!```$@`)`(`K
M````````I`$`````````;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`
M<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED
M`'-T<F-M<`!M96US970`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!L<W1A=`!C
M;&]S961I<@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S
M='(`<W1R8VAR`')E861L:6YK`%]?<W1A8VM?8VAK7V=U87)D`%]?8WAA7V9I
M;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`&-L;W-E`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T
M:6]N`&UK9&ER`'!T:')E861?9V5T<W!E8VEF:6,`;65M8W!Y`'-T<FQE;@!?
M7W-T86-K7V-H:U]F86EL`&=E='5I9`!097)L7W-Y<U]T97)M`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G
M971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L
M7W-V7S)P=E]F;&%G<P!?9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F
M;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T
M9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R
M;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`
M8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C
M`'!E<FQ?86QL;V,`9G!R:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`<F5A
M9&1I<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN
M`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM86%R8V@V-"YS;RXQ
M`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P
M871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT
M97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E
M;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?8G-S7W-T87)T
M7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R
M;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S
M<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``(";`0```````P0````````P
M(0```````(B;`0```````P0```````#0(````````("?`0```````P0`````
M``!0'@```````)B?`0```````P0````````83````````+"?`0```````P0`
M```````X&@````````"@`0```````P0`````````H`$``````!"@`0``````
M`P0````````H3````````!B@`0```````P0```````!33````````"B@`0``
M`````P0````````M3````````#"@`0```````P0````````M30```````#B@
M`0```````P0````````X3````````$"@`0```````P0````````_30``````
M`$B@`0```````P0```````!`3````````%B@`0```````P0```````!$3```
M`````&"@`0```````P0```````!)3````````'"@`0```````P0```````#A
M3@```````(B?`0```````00```4``````````````)"?`0```````00```8`
M`````````````*"?`0```````00```X``````````````*B?`0```````00`
M`!\``````````````+B?`0```````00``",``````````````,"?`0``````
M`00``"P``````````````,B?`0```````00``"\``````````````-"?`0``
M`````00``#$``````````````-B?`0```````00``#(``````````````."?
M`0```````00``#<``````````````.B?`0```````00``#P`````````````
M`/"?`0```````00``#T``````````````/B?`0```````00``$(`````````
M`````(B=`0```````@0```,``````````````)"=`0```````@0```0`````
M`````````)B=`0```````@0```<``````````````*"=`0```````@0```@`
M`````````````*B=`0```````@0```D``````````````+"=`0```````@0`
M``H``````````````+B=`0```````@0```L``````````````,"=`0``````
M`@0```P``````````````,B=`0```````@0```T``````````````-"=`0``
M`````@0```X``````````````-B=`0```````@0``!```````````````."=
M`0```````@0``!$``````````````.B=`0```````@0``!(`````````````
M`/"=`0```````@0``!,``````````````/B=`0```````@0``!0`````````
M``````">`0```````@0``!4```````````````B>`0```````@0``!8`````
M`````````!">`0```````@0``!<``````````````!B>`0```````@0``!@`
M`````````````"">`0```````@0``!D``````````````"B>`0```````@0`
M`!H``````````````#">`0```````@0``!L``````````````#B>`0``````
M`@0``!P``````````````$">`0```````@0``!T``````````````$B>`0``
M`````@0``!X``````````````%">`0```````@0``"```````````````%B>
M`0```````@0``"$``````````````&">`0```````@0``"(`````````````
M`&B>`0```````@0``"0``````````````'">`0```````@0``"4`````````
M`````'B>`0```````@0``"8``````````````(">`0```````@0``"<`````
M`````````(B>`0```````@0``"@``````````````)">`0```````@0``"H`
M`````````````)B>`0```````@0``"L``````````````*">`0```````@0`
M`"T``````````````*B>`0```````@0``"X``````````````+">`0``````
M`@0``#```````````````+B>`0```````@0``#$``````````````,">`0``
M`````@0``#(``````````````,B>`0```````@0``#,``````````````-">
M`0```````@0``#0``````````````-B>`0```````@0``#4`````````````
M`.">`0```````@0``#8``````````````.B>`0```````@0``#@`````````
M`````/">`0```````@0``#D``````````````/B>`0```````@0``#H`````
M``````````"?`0```````@0``#L```````````````B?`0```````@0``#X`
M`````````````!"?`0```````@0``#\``````````````!B?`0```````@0`
M`$```````````````""?`0```````@0``$$``````````````"B?`0``````
M`@0``$,``````````````#"?`0```````@0``$0``````````````#B?`0``
M`````@0``$4``````````````$"?`0```````@0``$8``````````````$B?
M`0```````@0``$<``````````````%"?`0```````@0``$@`````````````
M`%B?`0```````@0``$D``````````````&"?`0```````@0``$H`````````
M`````&B?`0```````@0``$L``````````````'"?`0```````@0``$T`````
M`````````/U[OZG]`P"1_7O!J,`#7]8``````````/![OZG0``"0$<)&^1`"
M-I$@`A_6'R`#U1\@`]4?(`/5T```D!'&1OD0(C:1(`(?UM```)`1RD;Y$$(V
MD2`"'];0``"0$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM```)`1UD;Y
M$*(VD2`"'];0``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1
MXD;Y$`(WD2`"'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM``
M`)`1[D;Y$&(WD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?
MUM```)`1^D;Y$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1
M(`(?UM```)`1!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D0
M8CB1(`(?UM```)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:
M1_D0PCB1(`(?UM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```
MD!$F1_D0(CF1(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6
MT```D!$R1_D0@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@
M`A_6T```D!$^1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B
M.I$@`A_6T```D!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'
M^1"".I$@`A_6T```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0
M$5Y'^1#B.I$@`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0
M``"0$6I'^1!".Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"
M'];0``"0$79'^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([
MD2`"'];0``"0$8)'^1`"/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y
M$$(\D2`"'];0``"0$8Y'^1!B/)$@`A_6T```D!&21_D0@CR1(`(?UM```)`1
MED?Y$*(\D2`"'];0``"0$9I'^1#"/)$@`A_6T```D!&>1_D0XCR1(`(?UM``
M`)`1HD?Y$`(]D2`"'];0``"0$:9'^1`B/9$@`A_6T```D!&J1_D00CV1(`(?
MUM```)`1KD?Y$&(]D2`"'];0``"0$;)'^1""/9$@`A_6T```D!&V1_D0HCV1
M(`(?UM```)`1ND?Y$,(]D2`"'];]>[NI_0,`D?-3`:G3``"PU```D/43`/GB
MAP.IXN,`D>$#`9'@3P"YX#,!D9'__Y?"``"0P```D$+\1_D`^$?YX0,"JB__
M_Y?```"0`,A'^0``0#F``0`U8O__EV+"`I%`#`#Y8```M2``@%*-__^7I/__
MEX#>1_D``$"YP?__EQ\D*3F4WD?Y@`)`N;W__Y<!:%(Y(0`?,@%H$CF``D"Y
MN/__EP%H4CDA```R`6@2.>!/0+D`%``1`'Q]DXG__Y?A(T#YXP,`JF+"`I$@
M`$#Y8```^0```/``;#N18`0`^<```+!#!`#Y`#A`^6`(`/D```#P`'@[D6`,
M`/F``(!20`0`N0``@-+B3T"Y``0`D5\``&L,!0!4=<("D4(,`!$$`(#2`0``
ML"'@&Y&@#D#Y?]@B^!/__Y?T`P`J@```-:`.0/E?__^7]`,`*G7"`I&@#D#Y
M-___EP```/``G#.1G```E&`!`+6@"D#YH```M0```/``<#*1E@``E*`*`/E@
MP@*1``A`^4```+3V!0"4<\("D6`.0/F&__^7J?[_E^`#%"KS4T&I]1-`^?U[
MQ:C``U_6!`P`$25X8/AEV"3XT___%QT`@-(>`(#2X`,`D:$``/`A0"Z1'^Q\
MD@$``!3B`P"JI```\*,``/"@``#PA,Q'^04`@-)CV$?Y`,!'^4&$0/@/__\7
M'R`#U1\@`]7```"0`.`!D<$``)`AX`&1/P``Z\```%2A``#P(=1'^6$``+3P
M`P&J``(?UL`#7];```"0`.`!D<$``)`AX`&1(0``RR+\?]-!#(&+(?Q!D\$`
M`+2B``#P0O!'^6(``+3P`P*J``(?UL`#7]8?(`/5_7N^J?T#`)'S"P#YTP``
MD&#B03D``@`UH```\`#H1_F```"TP```D```0/GU_O^7V/__EZ```/``T$?Y
M@```M"```-``H"F1>O[_ER``@%)@X@$Y\PM`^?U[PJC``U_6H```\`#L1_E`
M`0"T_7N_J<$``)`@``#0_0,`D2$``I$`H"F1X_[_E_U[P:C-__\7S/__%_U[
MO*G]`P"1\U,!J?5;`JGW8P.I``4`M/8#`*J@``#P`.!'^1<`0/EW!`"T^`,!
MJN(#%JI``$`Y'_0`<0080'HA`P!40@`62_4#%ZI3?$"3M`)`^=0!`+3B`Q.J
MX0,6JN`#%*I^_O^7(`(`-8!J<S@?]`!QP0$`5+4"%\MS!@"1E`(3B[7^0Y,5
M`P"YX`,4JO-30:GU6T*I]V-#J?U[Q*C``U_60@0`D>/__Q>U(@"1Z/__%Q0`
M@-+U__\7_7N^J:$``/#]`P"1(>1'^2(`0/GB#P#Y`@"`TN%3`)')__^7H0``
M\"'D1_GB#T#Y(P!`^4(``^L#`(#20```5/3^_Y?]>\*HP`-?UOU[O*G]`P"1
M\U,!J?,#`*J@``#PM```\/43`/D`Y$?Y]=,`D93B1_D!`$#YX1\`^0$`@-+A
M`Q6JX`,3JJ___Y<@`0"UH```\`#D1_GA'T#Y`@!`^2$``NL"`(#20`$`5-G^
M_Y>``D#YXC>`N0(,`HM`!$#Y0```^>#]_[1"(`"1_/__%_-30:GU$T#Y_7O$
MJ,`#7];]>[*IH0``\/T#`)$AY$?Y\U,!J?5;`JGW8P.I^2,`^2(`0/GB;P#Y
M`@"`TH`"`+0!`$`Y]`,`JB$"`#3-_?^7]@,`JL`!`+07``#0&```T/=.,9$8
M2S&1&0``T.`#%JKX_?^7\P,`JJ`!`+7@`Q:J(/[_E^`#%*IZ_O^7H```\`#D
M1_GA;T#Y`@!`^2$``NL"`(#20`4`5*;^_Y=S3@"1X0,7JN`#$ZKB_?^7@/W_
M-.$#&*K@`Q.JWOW_EP#]_S3@`Q2JE_[_E_4#`*K@`Q.JE/[_E[4"``NU"@`1
MH'Y`D_#]_Y?C`Q.JX@,4JO4#`*HA5S&1>_[_E^%C`9'@`Q6J:/[_EQ\$`#%`
M`0!4X&M`N0`,%!(?$$!QP0``5.`#%:JX__^7X`,5JEK^_Y?,__\7X`,5JM?]
M_Y?[__\7\U-!J?5;0JGW8T.I^2-`^?U[SJC``U_6_7NUJ:$``/#]`P"1(>1'
M^?,+`/GS`P"J(@!`^>)7`/D"`(#2X:,`D=G]_Y>``@`UX3M`N0(`E%(A#!02
M/Q!`<2000GK!``!4X`,3JD$`@%*'_?^7'P``<>`7GQJA``#P(>1'^>)70/DC
M`$#Y0@`#ZP,`@-*```!46?[_EP``@%+W__\7\PM`^?U[RZC``U_6_7NZJ?T#
M`)'U6P*I]0,`JJ```/#S4P&I\P,!J@#D1_GW8P.I^2,`^0$`0/GA+P#Y`0"`
MTF`"0#D?]`!Q00``5',&`)'@`Q.J/?[_E^%3`9'V`P"JX`,5J@K__Y?T`P"J
M(`(`M#;^_Y??`@#KZ`0`5`$`@-)@:F$X@&HA."$$`)&@__\UH```\`#D1_GA
M+T#Y`@!`^2$``NL"`(#20`D`5"O^_Y>T``#P@.)'^1D`0/D``(#2(B,`T?<#
M`"H`!`"107A@^*'__[7!``"0X`H`$2*P0+D`?'V3P@4`-.$#`*K@`QFJ-OW_
MEX'B1_D@``#YH/S_M)3B1_GA!@`1@`)`^1_8(?CW5P"YX0,5JB``0#D?]`!Q
M!!A`>B$%`%2T``#P]U>`N2$`%<O`"@"1E.)'^??R?=,`P"&+F`)`^6#]_Y<`
M:S?X`/K_M.%7@+F``D#Y`7AA^.(#`:J@%D`X(00`D2#P'SA@```T'_0`<4'_
M_U2@!X!20```.0``@-)B:F`X(F@@.``$`)&B__\UOO__%R(`@%(BL`"Y2?W_
ME_@#`*H@]_^TXGY]D^$#&:I(_?^7@.)'^1@``/G/__\7(00`D=/__Q?S4T&I
M]5M"J?=C0ZGY(T#Y_7O&J,`#7];]>[^IH```\/T#`)$`W$?Y``!`N;_]_Y?]
M>\&HH@``\",``-`!``#00O1'^6,8)9$A;#&1K_W_%_U[OJG]`P"1\PL`^;,`
M`/!SWD?Y8`)`N;#]_Y?K__^78`)`N:W]_Y?S"T#Y!```T/U[PJB$:#N1XP,$
MJ@4`@%("``"P`0``T$*@$9$AW#&1YOS_%PP*A-+_8RS+H```\/U[`*G]`P"1
M`.1'^?-3`:GTXP"1]1,`^0$`0/GA)Q#Y`0"`TNG\_Y?C`P`J!```T`(``-"$
M,#*10D`RD>`#%*HA`(+2S?S_EQ\$`#%!`0!4`P"`TJ```/``Y$?YX2=0^0(`
M0/DA``+K`@"`TB`%`%2:_?^7`7Q`DS\$0/%)``!4`'T@U&#^_S<`"(+2\V,@
MB^$#$ZK@`Q2J`@""TBO]_Y?T`P"J8/W_-P`$`!$`?$"3YOS_E^,#`*K`_/^T
ME7Y`DQ\`$^N"``!4```5BW\"`.N#_?]4?P`3ZXD``%1@`A6+?P``Z^/\_U0@
M`()2GP(`:XS\_U3@`P.JX@,5JN$#$ZIF_?^7XP,`JA]H-3C2__\7X`,#J@P*
MA-+]>T"I\U-!J?430/G_8RR+P`-?UK+__Q<,'(+2_V,LR_U[`*G]`P"1\U,!
MJ?0#`*J@``#P]5L"J?,#`:H`Y$?Y]V,#J?EK!*D!`$#YX6\(^0$`@-(```#0
M`'`RD57^_Y?W`P"JX06`4N`#%*K=_/^7H`$`M````-#A`Q2J`)0RD?W^_Y>@
M``#P`.1'^>%O2/D"`$#Y(0`"ZP(`@-)@"0!42/W_E^`#%*I"_?^7%0``T/@#
M`"JARC*1X`,3JAD``-`:``#0(_W_ESE/,9'S`P"J6M,RD?9C`Y'S_/^T8`)`
M.1\``'%S$IF:5P$`M.$#$ZK@`Q>J<_S_E\```#6ARC*1``"`TA/]_Y?S`P"J
M\___%^`#$ZHG_?^7`00`42-\0)-BRF$X7[P`<2`"`%0!!P`1(```"Q_\/W'L
M^?]4Y0,4JN0#&JKC`Q.JX`,6J@(``-`!`(+20A0VD4+\_Y<`!``1'P1`<:D`
M`%0`?2#4X`,!*G]J(SCI__\7X6,!D>`#%JKL_/^7P/O_->!K0+D`#!02'R!`
M<4'[_U3@`Q:J(0"`4BS\_Y?`^O\UX0,6J@```-``E#*1L/[_E^`#%JIU_/^7
M]`,`JK#__Q?@`Q2J#!R"TOU[0*GS4T&I]5M"J?=C0ZGY:T2I_V,LB\`#7];A
M`P"J(@!`.4(``#7``U_6(00`D5^\`'$`$(&:^O__%\`'`+3]>[ZI_0,`D?,+
M`/GS`P"J`0!`.<$``#4```#0`$PQD?,+0/G]>\*H5OS_%]W\_Y<"!`#18@("
MBW\"`NN"`P!40`!`.1^\`'&@`@!4?P("Z^("`%3@`P*J`?1?.#^\`'$A`@!4
M0@0`T7\"`NN"``!40`!`.1^\`'%@__]40@`3RT`(`)$?!$#Q*`,`5$($`)%?
M!$#QR0$`5`!](-1"!`#1YO__%^(#`*KI__\7?P("ZZ']_U1@`D`Y'[P`<>#Z
M_U0```#0`-`RD=;__Q?#``"08T`#D>$#$ZK@`P.J5?S_E_,+0/G]>\*HP`-?
MU@``@-+\__\7````T`!,,9'+__\7_7NZJ:```/#]`P"1`.1'^?-3`:D4``#0
M]5L"J18``-`3``#0`0!`^>$O`/D!`(#2(```T``8)9$5``#0`"@`D;7V,Y$"
M#$"IX@\#J0(,0:GB#P2I`$!`>>"C`'D```#0`-@RD:+]_Y<```#0`/PRD9_]
M_Y<```#0`!PSD9S]_Y<```#0`$`SD9G]_Y>`7C.1E_W_EP```-``G#.1E/W_
ME\!R,I&2_?^78,XSD9#]_Y?@`Q6JCOW_EP```-``'#21B_W_EP```-``E#*1
MB/W_EP```-``1#21<OW_EX```+3A`P"JX`,5JA_^_Y<```#0`(@TD6O]_Y?A
M`P"J@```M````-``M#"1%_[_EP```-``T#218_W_E^$#`*K@`0"TP'(RD1#^
M_Y>`7C.1`0``T"&`-9$,_O^7H```\`#D1_GA+T#Y`@!`^2$``NL"`(#2(`(`
M5%?\_Y<```#0`!`UD5#]_Y?A`P"J8```M&#.,Y'M__\7`0``T.`'`9$A5#61
M0@&`TJ_[_Y<`_?\UX2\!D??__Q?S4T&I]5M"J?U[QJC``U_6_7N^J?T#`)'S
M"P#YTP``D&`*0+D?!``Q00$`5````-``S#.1-OW_ET`!`+0``$`Y``$`-!_`
M`''@!Y\:8`H`N6`*0+GS"T#Y_7O"J,`#7]8``(!2^O__%_U[OZG]`P"1+_S_
ME[K[_Y=```"T``!`^?U[P:C``U_6_7N]J?T#`)'U6P*I%0``T+:*-9'S4P&I
M\P,`JN`#%JH9_?^7@```M`$`0#GT`P"JX0``->$#$ZJ@BC61\U-!J?5;0JG]
M>\.HP/W_%^$#$ZJ-^_^7@`(`M>`#$ZH*_/^7]0,`JN`#%*H'_/^7H`(`BP`(
M`)%D^_^7Y`,4JO4#`*KB`Q.J`P``T`$``-!CR#*1(10VD>S[_Y?A`Q6JX`,6
MJN?__Q?S4T&I]5M"J?U[PZC``U_6##*0TO]C+,OA(T"1_7L`J?T#`)'U6P*I
M]0,`JJ```/#S4P&I%@``T`#D1_GW8P.I^6L$J?LK`/D"`$#Y(L0`^0(`@-+`
M``"0`"``D0*,0*GB#P:I`@Q"J>(/":D"#$.IX@\*J0(,1*GB#PNI`@Q%J>*/
M!ZD!#$#YX3L`^0`P0/G@1P#YP'(RD=+\_Y<``P"T`0!`.?,#`*JA`@`TK/__
MEZ```/#A(T"1`.1'^2+$0/D#`$#Y0@`#ZP,`@-)```!4R/O_E^`#$ZH,,I#2
M_7M`J?-30:GU6T*I]V-#J?EK1*G[*T#Y_V,LBS+[_Q>0__^7\P,`J@`"`+7T
MXP&1@`)`^8```+43``#0<\HUD0H``!2P_/^78```M90B`)'X__\7`0!`.:'_
M_S0B^_^7\P,`JD#__[3@`Q.JIOO_EP#X?],7``#0``0`D??F-9$!^_^7^0,`
MJO0#`*IB`D`YH@D`-?1#`I&3`D#YDP$`M.`#$ZJ8_/^7\P,`JH`)`+0!`$`Y
M00D`-"#]_Y<`"0`TX`,3J@C[_Y?S`P"J]X,!D;,``+7T`D#Y=```M(`"0#D@
M"``UX`,3JH?[_Y?W`P"JX`,9JH3[_Y?W`@`+]Q(0$1@``+#W?D"3X`,7JM[Z
M_Y?E`QFJ`],RD>(#$ZH$``"PA/@UD?0#`*H!``"P(0PVD67[_Y?@`Q2J`3B`
M4DK[_Y<?!``Q`08`5$/[_Y<$`$"YGT0`<8`%`%2@``#0`0``L*("0/GC`Q2J
M`,1'^2$P-I$``$#Y'/O_EQ,`@-*@``#0X2-`D0#D1_DBQ$#Y`P!`^4(``^L#
M`(#2X?+_5.`#$ZH,,I#2_7M`J?-30:GU6T*I]V-#J?EK1*G[*T#Y_V,LB\`#
M7];@`Q2JX0,7JG,&`)&4"@"1//O_EZW__Q>4(@"1KO__%^`#%*K4_/^7@```
M-.`#%*J\^O^7\P,`JO<B`)&T__\7X0,#D>`#%*JN^O^7^0,`*D`!`#2@``#0
MXP,4JJ("0/D!``"P`,1'^2$<-Y$``$#Y[/K_E]#__Q?@TT"Y``P4$A\00'&!
M_O]4\]M`N37[_Y=_`@!K`?[_5.#30+D`(``2'P`'<8']_U3@`Q>JA?K_E_,#
M`*H```"P`+0UD2'\_Y=`"P"UMP)`^>`#%ZH=^_^7^@,`JA\,`'%M`P!4`'Q`
MDP$``+``$`#1(6@XD>`"`(M8^O^7@`(`-5\3`'&@``!46A<`4>#*>C@?O`!Q
MP0$`5+4&0/F5`0"TX`,5J@G[_Y<?#`#Q"0$`5``0`-$!``"PH`(`BR%\.)%&
M^O^7'P``<?<2E9K`_O^7(`T`->`#%ZH!`(!2=_K_E_4#`"J`#``T0@"`4B$"
M@)+W(P:1,?K_E^$#%ZK@`Q4JP@"`TKGZ_Y?@(T8Y(`8`->`G1CD?#`%QP04`
M5.`K1CD?!`%Q804`5.`O1CD?#`%Q`04`5.`S1CD?(`%QH00`5.`W1CD?%`%Q
M000`5$(`@%(A!X"2X`,5*ACZ_Y?A`Q>JX`,5*B(%@-*@^O^7!0``L.0#%ZJE
M:#N1`0``L`/3,I'B`Q2J(9`XD>`#$ZJ_^O^7X`,4JJGZ_Y?A`Q.JP'(RD7O\
M_Y?@`Q.JI_[_EV7__Q>W`D#Y/?K_E^$#`*K@`Q>J7/W_E_<#`*I`]/^UH/__
M%P(`@%(!`(#2X`,5*O?Y_Y=@!0"4^0,`J@(`D-+A`Q>JX`,5*GWZ_Y?B`P"J
M'P``<2P#`%3@`Q4J]V,%D6_Z_Y?[`Q>JX0,9JAD``+`YYS61%0"`TOH#!9'@
M`QJJP`4`E$)K=3C@`Q>JX0,9JK4&`)'W"@"1D?K_E[]2`/$A__]4!0``L.0#
M&ZJE:#N1_P,&.<;__Q?A`Q>JX`,9JE0%`)3>__\7`0``L````+`A@#61`,PS
MD1<``+#W!CF10/S_EQC3,I'-^?^7%0``L+5J.Y'D`P`JY0,5JN,#&*KB`Q2J
MX`,3J@$``+`AS#B1<_K_E^`#$ZH!.(!26/K_EQ\$`#$!]O]44?K_EP``0+D?
M1`!Q@?7_5+GY_Y<Y!P`1Y`,`*N8#%:KE`QDJXP,8JN(#%*KA`Q>JX`,3JF#Z
M_Y?M__\7_7NZJ?T#`)'S4P&ILP``T/5;`JEUWD?Y]V,#J?EK!*G[<P6IH`)`
MN5#Z_Y?T`P"JH`)`N4WZ_Y>!XD(Y`>0".0```+``7#.17/O_E\```+0!`$`Y
M/\0`<6$``%0`!$`Y0```-*W]_Y=WWD?YM```\.`"0+D]^O^7`0``L&,!@%(A
M2#F1(@"`4M3Y_Y<@!`"U=MY'^<`"0+DT^O^78P"`4B(`@%(!``"P(5PYD<OY
M_Y?U`P"JX`D`M7?>1_G@`D"Y*OK_EV,`@%(B`(!2`0``L"'<.9'!^?^7]0,`
MJB`,`+0```"P`)0RD33[_Y?V`P"J(`H`M.`"0+D<^O^7H0I`^>(#%JHA`$#Y
MO/G_EU4``!0`"$#Y&X"`4IK"`I$U`(!2&P2@<A@40/FY!@!100=`N>`"0+D_
M`!5K#0$`5`OZ_Y<B?T"3X0,8J@,`@%)K^?^7]@,`JB`!`+66P@*1P`9`N0`$
M`%$?`!EK0?G_5'?>1_DU`(!2&@``%`$`0/E`!T#Y'-AU^"`,0+D``!L*'P`0
M<>$``%0A"$#YX`,<JDOY_Y?`_?\UM08`$>#__Q?@`D"Y[OG_E\$"0/E#`(!2
M`@"`TOKY_Y?A`P"J]/__%[4&`!'F^?^7X0,8JA#Y_Y?!!D"YX`)`N3\`%6LL
M__]4J?__%\`"0+G=^?^7H0I`^0(``+!"9#F1(0!`^7SY_Y>@"D#Y``!`^0`,
M0+D`];<VP`)`N=+Y_Y>A"D#Y(0!`^3OY_Y>B__\7+/S_E_8#`*K@`D"Y]@0`
MM,GY_Y>A"D#YX@,6JB$`0/EI^?^7X`,6JK/Y_Y=SWD?Y8`)`N<#Y_Y?U`P"J
M8`)`N;WY_Y<B`(!2`0``L"%X.9'Q^/^7`@``L.$#`*I"S#F1X`,5JECY_Y=@
M`D"YD\("D;'Y_Y<?Y`(Y````L`!P,I'!^O^78`H`^<`!`+5@!D#YR?W_EV`*
M`/E``0"U````L`#D.9'L^/^7H_G_EX'"`I$B!$#YH0I`^4(`0/F%__\7E,("
MD0$X@%*`"D#YAOG_E^,#`"H?1`!Q(`$`5``$`!$?!`!QR0``5("*0*D!`$#Y
M````L`!H.I'7^/^7\U-!J?5;0JGW8T.I^6M$J?MS1:G]>\:HP`-?UOU[OJG]
M`P"1\U,!J?,#`*JN_/^7I?S_E_0#`*I5_?^7P`$`-+,!`+1@`D`Y8`$`-`$`
M`+#@`Q2J(?@UD0SY_Y>?`@#KH0``5.`#$ZKS4T&I_7O"J+[Z_Q?S4T&I_7O"
MJ,`#7];_@PK1H0``T`7@`)$'X`&1_7L`J?T#`)$AY$?Y(@!`^>)/`?D"`(#2
MXF,`D>8#`JJA`$"YQD``D:2$0/@A",!:P0`?^('\8-,C'`A3(=QXTR$<<))A
M``&J@_QHTV,<>))DX$2J(0`$JL&`'_C_``7K`?[_5`,(@%)$($#Y8P0`<4$T
M0/E"(`"118!?^"$`!,I$!$#YA``%RB$`!,HD_%_3@00!JB%\0))!/`#Y8?[_
M5`4@0*DJ,X_2!AQ!J4I0J_()$$#YI/Q;TP/]0M.$%`6J8W@(JN$`!LJL_$+3
M(0`(BHQY!:HA``?*CGU`DB1`)(OABT&I(0`*BT(`"HN$``&+87Q`DBL`!LJ$
M``D+:P$%BF,`#,IK`0;*8P`$BFL!!XMC``'*:P$"BX+\6]-"%`2J8P`&BVL!
M`@OB%T#Y0@`*BV,``HMB_5O30A0+JF,``@N"_$+31'@$JH(!!,J-?$"20@`+
MBD(`#LI"``&+X1M`^2$`"HM"``&+8?Q;TR$4`ZI"``$+8?U"TRMX"ZJ!``O*
M;'U`DN0?0/DA``.*(0`-RH0`"HLA``Z+(0`$BT3\6].$%`*J(0`$"V3\0M.#
M>`.J:P$#RFY\0)+D(T#Y:P$"BFL!#,J$``J+:P$-BVL!!(LD_%O3A!0!JFL!
M!`M$_$+3@G@"JF0``LI-?$"2XR=`^80``8J$``[*8P`*BX0`#(N$``.+8_U;
MTV,4"ZJ$``,+(_Q"TV%X`:I#``'*+'Q`DN(K0/EC``N*8P`-RD(`"HMC``Z+
M8P`"BX+\6]-"%`2J8P`""V+]0M-+>`NJ(@`+RFY]0)+A+T#Y0@`$BD(`#,HA
M``J+0@`-BT(``8MA_%O3(10#JD(``0N!_$+3)'@$JFL!!,J-?$"2X3-`^6L!
M`XIK`0[*(0`*BVL!#(MK`0&+0?Q;TR$4`JIK`0$+8?Q"TR-X`ZJ!``/*;'Q`
MDN0W0/DA``**(0`-RH0`"HLA``Z+(0`$BV3]6].$%`NJ(0`$"T3\0M.">`*J
M9``"RDY\0)+C.T#YA``+BH0`#,IC``J+A``-BX0``XLC_%O38Q0!JH0``PMC
M_4+3:W@+JD,`"\IM?4"2XC]`^6,``8IC``[*0@`*BV,`#(MC``*+@OQ;TT(4
M!*IC``(+(OQ"TT%X`:IK`0'*+'Q`DN)#0/EK`02*:P$-RD(`"HMK`0Z+:P$"
MBV+\6]-"%`.J:P$""X+\0M-$>`2J(@`$RHY\0)+A1T#Y0@`#BD(`#,HA``J+
M0@`-BT(``8MA_5O3(10+JD(``0MA_$+3(W@#JH$``\IM?$"2Y$M`^2$`"XHA
M``[*A``*BR$`#(LA``2+1/Q;TX04`JHA``0+9/U"TX1X"ZIK``3*C'Q`DN-/
M0/EK`0**:P$-RF,`"HMK`0Z+:P$#BR/\6]-C%`&J:P$#"T/\0M-B>`*J@P`"
MRD]\0)+D4T#Y8P`!BF,`#,IN_5O3A``*BV,`#8MC``2+)/Q"TX%X`:K.%0NJ
M0@`!RF,`#@M"``N*)'Q`DD(`#\IM_%O30@`,BZT5`ZKL5T#Y;OQ"TXP!"HM"
M``R+;/U"TXMY"ZI10"V+(0`+RJ(!`@LA``.*PWD#JNQ;0/DA``3*(0`/BT_\
M6]/O%0*JB@$*BTW\0M,A``J+K7D"JC!`+XMB``W*:@$#RD(`$$I*`1%*2@$$
MBTM`*XODBTNIX0$!"RQTG=(LVZWR+_Q"TX0`#(M"``R+2@$$BR3\6].$%`&J
M:P$"B^%Y`:I1022+B@`*"ZX!`<I"_5O31/U"TT(4"JJ*>`JJS@$12G!!(HM+
M``L+(@`*RLY!(XM"`!!*9/U"TTU`+8OCBTRI8P`,BT(`#(O.`0.+8_U;TV,4
M"ZJ+>`NJ3P$+RJT!`HO102.+8P`."^\!$4IB_%O3;OQ"TT(4`ZKO02&+PWD#
MJN&[3:FP02*+0@`-"V0!`\J$`!!*3?Q"TX1`*HLA``R+S@$,B^\!`8M!_%O3
M(10"JJ)Y`JIJ``+*A``.B_%!(8LA``\+2@$12C#\6],O_$+3$!8!JN%Y`:I*
M02N+2P`!RHY`,(L$`@0+:P$.2F-!(XN0_%O3[:].J1`6!*J._$+3Q'D$JJT!
M#(MK`0R+2@$-BRT`!,I103"+"@(*"ZT!$4IC``N+HD$BBTO]6]/M?T#Y:Q4*
MJJT!#(MO0"N+0@`-BTW]0M.J>0JJ:P$#"X,`"LIC``]*</U;TV%`(8L0%@NJ
MXX-`^5%`,(L"`@(+8P`,BR$``XMC_4+3:W@+JD_\6]-.`0O*[Q4"JLX!$4K.
M022+1/Q"TX)X`JHR0"^+XY-0J>$!`0MM`0+*+_Q;TZT!$DKO%0&JK4$JBRK\
M0M-C``R+07D!JLX!`XM#``'*T4$OB^X!#@MC`!%*A``,BVM`*XO/_5O3XX]`
M^>\5#JJM`02+8P`,B[!!+XMK`0.+P_U"TVYX#JKM`0T+)``.RH0`$$JO_5O3
MA$`BB^\5#:KBDT#Y<4$OB^L!"PM"``R+A``"BZ+]0M-->`VJ;_U;T\H!#<KO
M%0NJ2@$12DI!(8N00"^+X9=`^>0!!`LA``R+C_Q;TTH!`8MA_4+3(7@+JN\5
M!*JC`0'*8P`02E%!+XMC0"Z+COQ"T\1Y!*KJ`0H+(@`$RD(`$4I/_5O30D`M
MB^\5"JKK-U.I:P$,BZT!#(MC``N+0@`-BW!`+XOC`0,+2_U"TV_\6]-M_$+3
M[Q4#JFIY"JJC>0.JBP`*RE%`+XM.`0/*:P$02LX!$4IA02&+SD$DB^L35*GB
M`0(+3_Q;T^\5`JIK`0R+A``,BR$`"XO.`02+,$`OB^$!`0LD_%O3A!0!JLX!
M!`M$_$+3@G@"JFL``LKDJT#Y:P$02FM!*HLJ_$+307D!JHP`#(ML`0R+2P`!
MJBT``@IK`0Z*;0$-JL3]6].M02.+A!0.JN.O0/F,`00+BYN7TFOCL?)C``N+
MK0$#BX/]6]-C%`RJK0$#"\/]0M-N>`ZJ+P`.JL0!`0KO`0R*Y`$$JH1`(HOB
MLT#Y0@`+BX0``HNB_5O30A0-JH0``@N"_4+33'@,JL\!#*J*`0X*[P$-BNH!
M"JI*02&+X;=`^2$`"XM*`0&+@?Q;TR$4!*I*`0$+H?U"TRUX#:J/`0VJHP$,
M"N&[0/GO`02*XP$#JB$`"XMC0"Z+8P`!BT']6],A%`JJ8P`!"X'\0M,D>`2J
MK@$$JH(`#0KAOT#YS@$*BL(!`JHA``N+0D`LBT(``8MA_%O3(10#JD(``0M!
M_4+3*G@*JHP`"JI!`00*C`$#BH$!`:KLPT#Y(4`MBXP!"XLA``R+3/Q;TXP5
M`JHA``P+;/Q"TX-Y`ZI,`0.J;0`*"HP!`HJ,`0VJA$$DB^S'0/F,`0N+A``,
MBRS\6].,%0&JA``,"TS\0M.">0*J;``"JDT``PJ,`0&*C`$-JHI!*HOLRT#Y
MC`$+BTH!#(N,_%O3C!4$JDH!#`LL_$+3@7D!JDP``:HM``(*C`$$BHP!#:J#
M02.+[,]`^8P!"XMC``R+3/U;TXP5"JIC``P+C/Q"TX1Y!*HL``2JC0`!"HP!
M"HJ,`0VJ@D$BB^S30/F,`0N+0@`,BVS\6].,%0.J0@`,"TS]0M.*>0JJC``*
MJDT!!`J,`0.*C`$-JH%!(8OLUT#YC`$+BR$`#(M,_%O3C!4"JB$`#`ML_$+3
M@WD#JDP!`ZIM``H*C`$"BHP!#:J$022+[-M`^8P!"XN$``R++/Q;TXP5`:J$
M``P+3/Q"TX)Y`JIL``*J30`#"HP!`8J,`0VJBD$JB^S?0/F,`0N+2@$,BXS\
M6].,%02J2@$,"RS\0M.!>0&J3``!JBT``@J,`02*C`$-JH-!(XOLXT#YC`$+
MBV,`#(M,_5O3C!4*JF,`#`N,_$+3A'D$JBP`!*J-``$*C`$*BHP!#:J"02*+
M[.=`^8P!"XM"``R+;/Q;TXP5`ZI"``P+3/U"TXIY"JJ,``JJ30$$"HP!`XJ,
M`0VJ@4$AB^SK0/F,`0N+(0`,BTS\6].,%0*J(0`,"VS\0M.#>0.J3`$#JFT`
M"@J,`0**C`$-JH1!)(OL[T#YC`$+BX0`#(LL_%O3C!4!JH0`#`M,_$+3@GD"
MJFP``JI-``,*C`$!BI#\6].,`0VJ$!8$JHI!*HOL\T#YC`$+BTH!#(LL_$+3
M@7D!JDH!$`M,``&J+0`""HP!!(I/_5O3C`$-JN\5"JJ#02.+4/U"T^SW0/F,
M`0N+8P`,BVU`+XOO`0,+@_Q"TV1X!*KN_5O3+``$JH,``0J,`0J*SA4/JHP!
M`ZH*>@JJX_M`^8)!(HMK``N+X_U"TT(`"XO+.IC23$`NB\X!`@N"``K*2TRY
M\D(`#4K-_5O304`ABZT5#JKB_T#Y;W@/JD(`"XLA``*+POU"TS)`+8NM`0$+
M00$/RDYX#JHA``Q*\`$.RB1`)(NL_5O3X0-!^1`"$DJ,%0VJ$$(JBR$`"XOJ
M!T'YA``!BY%`+(N,`00+2@$+BZ']0M,0`@J+BOU;TRUX#:I*%0RJY`M!^<,!
M#<H>0BJ+8P`12DH!$`N$``N+;T`OB^\!!(M1_5O3A/U"TS$6"JJ,>`RJ4/U"
MT^,/0?FB`0S*"GH*JO)!,8M"`!Y*+P(/"V,`"XN!`0K*3D`NBR$`$DK.`0.+
MX_U;TV,4#ZHM0"V+X1-!^<)!(XOD_4+38P`."X]X#ZHA``N+K0$!BT0!#\IA
M_%O3A``"2B$4`ZJ,0"R+XA=!^;!!(8LA``T+;OQ"TT(`"XO#>0.JC`$"BR+\
M6]-"%`&J[@$#RLX!$$HM_$+3D4$BB\I!*HM"``P+H7D!JNX;0?E0_%O3$!8"
MJF0``<K.`0N+3/Q"TTH!#HN">0*J3D$PBPH""@OM'T'YA``12BP``LJ$0"^+
M3_U;TZT!"XOO%0JJC`$.2D[]0M.$``V+RGD*JI%`+XM-``K*Y`$$"ZT!$4J#
M02.+H4$ABX_\6]/M)T'Y[Q4$JNPC0?FM`0N+(0`-BXW\0M.,`0N+I'D$JF,`
M#(M,`03*<D`OB^,!`PN,`1)*@D$BBV_\6]/L*T'Y[Q4#JHP!"XLQ0"^+0@`,
MBVS\0M.#>0.JX0$!"XX``\K.`1%*+_Q;T\Y!*HOO%0&JZB]!^5!`+XOB`0(+
M2@$+B\X!"HLJ_$+307D!JD_\6]-M``'*[Q4"JJT!$$JM022+T4$OB^0S0?GN
M`0X+A``+B\_]6].M`02+1/Q"TX)X`JKO%0ZJ+``"RHP!$4JP02^+C$$CB^T!
M#0OC-T'YK_U;T^\5#:IC``N+C`$#B\/]0M-N>`ZJD4$OBTH`#LKL`0P+2@$0
M2DI!(8N/_5O3X3M!^>\5#*HA``N+2@$!BZ']0M,M>`VJ4$$OB\0!#<KJ`0H+
MA``12H_]0M.$0"*+['D,JN(_0?FC`0S*8P`02D_]0M-"``N+8T`NBX0``HM"
M_5O30A0*JNIY"JJ!`0K*I4`LBY%`(HM"``0+Y$-!^4[\6]/.%0*J(0`12H0`
M"XLA0"V+8P`$BT3\0M-P0"Z+PP$#"^Y'0?F">`*J30$"RDD!"0O.`0N+K0$0
M2B$`#HMN_%O3SA4#JD(`!PLA``X+`J0!J23\6].$%`&J(0`("X0`#8OM2T'Y
MJP$+BV4!!8N%``4+!00`J6'\0M,A>`.J)@`&"P8(`/F@``"P`.1'^>%/0?D"
M`$#Y(0`"ZP(`@-)```!48O7_E_U[0*G_@PJ1P`-?UOU[OZD`$(#2_0,`D;?T
M_Y<?_`*I(F"$TJ+HK/("``#Y(G&5TA]X`+FB^;WR`@0`^<*?F])"%[/R`@@`
M^<*.BM)"!J+R`@P`^0(^G-)">KCR`A``^?U[P:C``U_6_7N\J?T#`)'S4P&I
M\P,`JD!\0)/U6P*I]`,`JF(60/GW&P#Y0PP`"U\``^N)``!48AI`^4($`)%B
M&@#Y8AI`^77B`)%`=$"+8X("J6!Z0+F``P`T%@B`4M8"`$N?`A9KH,(@BY;2
MEAK"?D"3'P`!ZZ(``%0#``*+/P`#ZT(``%0`?2#4-P`"BQ\``>MI``!4'P`7
MZV/__U01]?^78'I`N<`"``M@>@"Y'P`!<<$"`%3@`Q.JE/O_EY0"%DOA`Q>J
M=^(!D9_^`'&,`@!4@GY`DS\`%>N)``!4H`("BS\``.L#_?]4/P`5ZX(``%0@
M``*+OP(`ZV/\_U3@`Q6J^/3_EW1Z`+GS4T&I]5M"J?<;0/G]>\2HP`-?UC\`
M%>MI``!4/P`7Z^/Z_U0V``&1OP(!ZVD``%2_`A;K0_K_5"(,0*FB#@"IE`(!
M42(,0:FB#@&I(@Q"J:(.`JD@!$.IH`8#J>`#$ZIH^_^7X0,6JM;__Q?]>[RI
M_0,`D?-3`:GT`P"J\P,!JO5;`JDUX`"1]QL`^2`40/DV*$"Y-S!`N>$/@!(`
M(`-3U@K`6@($`!'W"L!:H<H@.*#"(HM?X`!QC0D`5`$(@%(B``)+`0"`4D)\
M0),C]/^7X`,3JDO[_Y=__@.I?_X$J7_^!:E_-@#Y=UH.*>`#$ZI$^_^78`)`
M^0#\6-.``@`Y8`)`^0#\4-.`!@`Y8`)`^0#\2-.`"@`Y8`)`^8`.`#E@!D#Y
M`/Q8TX`2`#E@!D#Y`/Q0TX`6`#E@!D#Y`/Q(TX`:`#E@!D#Y@!X`.6`*0/D`
M_%C3@"(`.6`*0/D`_%#3@"8`.6`*0/D`_$C3@"H`.6`*0/F`+@`Y8`Y`^0#\
M6-.`,@`Y8`Y`^0#\4-.`-@`Y8`Y`^0#\2-.`.@`Y8`Y`^8`^`#E@$D#Y`/Q8
MTX!"`#E@$D#Y]5M"J0#\4-.`1@`Y8!)`^0#\2-.`2@`Y8!)`^8!.`#G@`Q.J
M\U-!J?<;0/G]>\2H9?3_%P$'@%(B``)+`0"`4D)\0)/8\_^7N___%_U[OZG]
M`P"1_7O!J,`#7]8O=&UP`%!!4E]435!$25(`5$5-4$1)4@!435``55-%4@!5
M4T523D%-10`N+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0
M`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!0
M15),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!0
M05)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!
M3%]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%2
M7T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`)3`R>`!P87(M`"5S
M)7,E<R5S`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H`)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`%!!4CHZ4&%C
M:V5R.CI615)324].`#$N,#4P`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`+64`+2T`979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E
M8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]
M*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@
M/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN
M+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A
M<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*
M9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP
M+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64[
M"FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q
M("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@
M)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B10
M05)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O
M<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(
M+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`]
M(#8T("H@,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N
M:U]S:7IE*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D
M<VEZ92`E("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE
M("T@)&T["GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S
M:7IE.PI]"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:RA?1D@L("1M
M86=I8U]P;W,L(#`I.PIR96%D*%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L
M96YG=&@H)%!!4E]-04=)0RDI.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L
M("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0[
M"GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I
M8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@
M7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A
M8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R
M97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F
M.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY
M("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U
M*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?
M=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B
M4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R
M97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5]
M(#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/
M.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*
M<')I;G0@)&9H("1I;F9O+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U
M<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1I
M;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G
M/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D
M(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@
M0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?
M;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE
M("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P
M('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H
M)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E
M9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A
M<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P
M87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*
M<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'
M5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T
M;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"
M3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U
M<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A
M;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A
M<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*
M?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS
M:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q
M(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E
M;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE
M(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D[
M"G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II
M9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF
M="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@
M)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O
M('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%
M5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^
M(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<[
M"GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!
M4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^
M(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*
M,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE
M9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@
M,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O
M<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*
M;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM
M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R
M(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE
M;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!0
M05(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN
M:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![
M("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D
M7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S
M.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J
M96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N
M9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES
M("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER
M("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%
M7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I
M.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:
M(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L
M<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO
M:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO
M<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE
M.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S
M92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^
M<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N
M86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R
M8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H
M+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L
M92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N
M86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIO<&5N*&UY("1F:"P@(CPB+"`D;W5T*3L*8FEN;6]D92@D9F@I.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C86-H95]N86UE(#T@
M)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B
M.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H
M)%!!4E]-04=)0RD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X
M:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?
M<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O
M;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHD>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0
M?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L
M<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S
M=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!
M;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@
M6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP
M87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H
M:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`
M7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A
M=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@
M*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK
M<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W
M:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB
M.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER
M92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q
M=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*
M<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR
M97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q
M=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![
M(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE
M=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L
M('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*
M979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A
M8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@
M+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T
M:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L
M('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]
M("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@
M>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%
M3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S
M97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF
M:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F
M:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D
M("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]
M?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("1B=68["GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D[
M"F]P96XH;7D@)&9H+"`B/"(L("1P<F]G;F%M92D["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E
M<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM0
M05)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E
M;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W
M<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D
M8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[
M4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE
M*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N
M9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6
M>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]
M?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G
M;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97
M:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO
M;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?
M9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H
M("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E
M;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!3
M4$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*
M9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!
M3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R
M("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@
M)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R
M;'AS:2YC`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````$;
M`SOP````'0```-R4__\8!0``[);__P@!```<E___'`$``%R7__\P`0``O)?_
M_U0!``#PE___=`$``*R8__^H`0``^)C__\@!``",F?__\`$``.":__\H`@``
M<)O__TP"``!,G?__A`(``(2=__^D`@``V)W__\@"```0G___^`(``!2?__\,
M`P``Z*#__U`#```(H?__9`,```RB__^@`P``L*/__\P#```(I/__\`,``"BD
M__\0!```W*3__T@$``#TJO__J`0``$"N___H!```I*[__T0%``!$O___:`4`
M`*"___^(!0``$,'__[P%```0``````````%Z4@`$>!X!&PP?`!`````8````
MW)7__S``````````$````"P```#XE?__/``````````@````0````"26__]@
M`````$$.()T$G@-"DP)4WMW3#@`````<````9````&"6__\T`````$0.$)T"
MG@%'WMT.`````#````"$````=);__[P`````00Y`G0B>!T23!I0%E026`Y<"
MF`%C"M[=U]C5UM/4#@!!"P`<````N````/R6__],`````$$.()T$G@-1WMT.
M`````"0```#8````*)?__Y0`````00Y`G0B>!T*3!I0%1)4$7=[=U=/4#@`T
M``````$``)27__]4`0```$$.X`&=')X;1Y,:E!F5&)87EQ:8%9D4`DS>W=G7
MV-76T]0.`````"`````X`0``L)C__Y``````00ZP`9T6GA5$DQ1>WMW3#@``
M`#0```!<`0``')G__]P!````00Y@G0R>"T*5")8'0Y,*E`E$EP:8!9D$`FS>
MW=G7V-76T]0.````'````)0!``#`FO__.`````!!#A"=`IX!1M[=#@`````@
M````M`$``-B:__]4`````$$.()T$G@-"DP)*WMW3#@`````L````V`$```B;
M__\X`0```$(.T$!"G8H(GHD(0Y.(")2'"$*5A@@"1-W>U=/4#@`0````"`(`
M`!"<__\$`````````$`````<`@```)S__]0!````0@[@(4&=G`2>FP1"DYH$
ME)D$1Y68!):7!)>6!)B5!)F4!)J3!`)HW=[9VM?8U=;3U`X`$````&`"``"0
MG?__(``````````X````=`(``)R=__\$`0```$(.()T$G@-"DP)'WMW3#@!!
M#B"3`IT$G@-O"M[=TPX`00M"#@#3W=X````H````L`(``&2>__^D`0```$$.
M8)T,G@M$DPJ4"4*5")8'`F'>W=76T]0.`"````#<`@``W)___U@`````00X@
MG02>`T*3`E`*WMW3#@!!"QP``````P``$*#__R``````00X0G0*>`4;>W0X`
M````-````"`#```0H/__M`````!!#C"=!IX%0I4"E@%#DP24`TP*WMW5UM/4
M#@!!"UG>W=76T]0.``!<````6`,``(R@__\8!@```$(.D(,"0IVR()ZQ($*5
MKB"6K2!(D[`@E*\@EZP@F*L@F:H@FJD@FZ@@;`K=WMO9VM?8U=;3U`X`00L"
M:`K=WMO9VM?8U=;3U`X`00L````\````N`,``$2F__],`P```$$.8)T,G@M"
MDPJ4"4*5")8'1)<&F`69!)H#FP*<`0+)WMW;W-G:U]C5UM/4#@``+````/@#
M``!0J?__9`````!!#B"=!)X#0I,"E`%2"M[=T]0.`$$+0M[=T]0.````*```
M`"@$``"\C___Q`$```!!#E"="IX)0I,(E`=#E08"9@K>W=73U`X`00L@````
M5`0``%BI__^@$````$$.H`5$G52>4P,B!-W>#@`````<````>`0``-2Y__]<
M`````$$.$)T"G@%5WMT.`````#````"8!```$+K__W`!````00Y`G0B>!T*3
M!I0%1I4$E@.7`GP*WMW7U=;3U`X`00L````P````S`0``$R[__^4`0```$$.
M0)T(G@="DP:4!4.5!)8#0I<"`E8*WMW7U=;3U`X`00L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#`A````````T"`````````!
M`````````"@#`````````0`````````S`P````````\`````````@00`````
M```,`````````#@:````````#0`````````83````````!D`````````@)L!
M```````;``````````@`````````&@````````"(FP$``````!P`````````
M"`````````#U_O]O`````"`"````````!0`````````0#0````````8`````
M````"`,````````*`````````)\$````````"P`````````8`````````!4`
M```````````````````#`````````'"=`0```````@````````#0!0``````
M`!0`````````!P`````````7`````````&@4````````!P````````"P$0``
M``````@`````````N`(````````)`````````!@`````````&```````````
M`````````/O__V\``````0``"`````#Y__]O`````!``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````4!H```````!0&@```````%`:````````4!H```````!0&@``
M`````%`:````````4!H```````!0&@```````%`:````````4!H```````!0
M&@```````%`:````````4!H```````!0&@```````%`:````````4!H`````
M``!0&@```````%`:````````4!H```````!0&@```````%`:````````4!H`
M``````!0&@```````%`:````````4!H```````!0&@```````%`:````````
M4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````D)L!``````!0'@`````````````````````````````83```
M```````````````````````````X&@``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@`0``````_____P`````H3````````%-,````````````
M```````M3````````"U-````````.$P````````_30```````$!,````````
M``````````!$3````````$E,``````````````````#A3@```````$=#0SH@
M*$%L<&EN92`Q,"XR+C%?<')E,2D@,3`N,BXQ(#(P,C`Q,C`S```N<VAS=')T
M86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y
M;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A
M;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````
M````````````````````````````````````````````````````````````
M```````+`````0````(```````````(``````````@```````!H`````````
M```````````!````````````````````$P```/;__V\"`````````"`"````
M````(`(```````#H``````````,`````````"````````````````````!T`
M```+`````@`````````(`P````````@#````````"`H````````$`````P``
M``@`````````&``````````E`````P````(`````````$`T````````0#0``
M`````)\$```````````````````!````````````````````+0````0````"
M`````````+`1````````L!$```````"X`@````````,`````````"```````
M```8`````````#<````$````0@````````!H%````````&@4````````T`4`
M```````#````$0````@`````````&`````````!!`````0````8`````````
M.!H````````X&@```````!`````````````````````$````````````````
M````/`````$````&`````````%`:````````4!H`````````!```````````
M````````$````````````````````$<````!````!@````````!0'@``````
M`%`>````````R"T``````````````````!````````````````````!-````
M`0````8`````````&$P````````83````````!`````````````````````$
M````````````````````4P````$````"`````````"A,````````*$P`````
M``!*/0```````````````````0```````````````````%L````!`````@``
M``````!TB0```````'2)````````]`````````````````````0`````````
M``````````!I`````0````(`````````:(H```````!HB@`````````%````
M```````````````(````````````````````<P````X````#`````````(";
M`0``````@)L````````(````````````````````"``````````(````````
M`'\````/`````P````````"(FP$``````(B;````````"```````````````
M``````@`````````"`````````"+````!@````,`````````D)L!``````"0
MFP```````.`!````````!``````````(`````````!``````````E`````$`
M```#`````````'"=`0``````<)T```````"0`@``````````````````"```
M```````(`````````)D````!`````P``````````H`$```````"@````````
M>`````````````````````@```````````````````"?````"`````,`````
M````>*`!``````!XH````````%@0```````````````````(````````````
M````````I`````$````P````````````````````>*`````````J````````
M`````````````0`````````!``````````$````#````````````````````
L`````**@````````K0````````````````````$`````````````````````
